@@ -35,7 +35,7 @@ class Domoticz(IPlugin):
 		bodies = ""
 		entity = jsonInput['outcome']['entities']['value']
 		log.msg("entity :  %s" % (entity))		
-#		if jsonInput['outcome']['entities']['location']['value'] :
+		if jsonInput['outcome']['entities']['location']['value'] :
 			location = jsonInput['outcome']['entities']['location']['value']
 #		else:
 #			bodies = "pas de lieu"
